==> 2.5.0.zip: cloudlog/application/language/german/account_lang.php <==
<?php

defined('BASEPATH') OR exit('Direkter Zugriff auf Skripte ist nicht erlaubt');

$lang['account_logbook_fields'] = 'Logbuchfelder';
$lang['account_column1_text'] = 'Wähle Spalte 1';
$lang['account_column2_text'] = 'Wähle Spalte 2';
$lang['account_column3_text'] = 'Wähle Spalte 3';
$lang['account_column4_text'] = 'Wähle Spalte 4';
$lang['account_column5_text'] = 'Wähle Spalte 5 (nur für Logbuch)';

$lang['account_create_user_account'] = 'Benutzerkonto anlegen';
$lang['account_edit_account'] = 'Benutzerkonto editieren';

$lang['account_account_information'] = 'Bnutzerkonto Informationen';
$lang['account_user'] = "Benutzer";
$lang['account_word_edited'] = "bearbeitet";
$lang['account_username'] = 'Benutzername';
$lang['account_email_address'] = 'Emailadresse';
$lang['account_password'] = 'Passwort';

$lang['account_roles'] = 'Rollen';
$lang['account_user_role'] = 'Benutzerrolle';
$lang['account_word_admin'] = 'Admin';

$lang['account_theme'] = 'Thema';
$lang['account_stylesheet'] = 'Stylesheet';

$lang['account_personal_information'] = 'Informationen';
$lang['account_first_name'] = 'Vorname';
$lang['account_last_name'] = 'Nachname';
$lang['account_callsign'] = 'Rufzeichen';
$lang['account_gridsquare'] = 'Planquadrat';

$lang['account_cloudlog_preferences'] = 'Cloudlog Einstellungen';
$lang['account_timezone'] = 'Zeitzone';
$lang['account_date_format'] = 'Datumsformat';
$lang['account_log_end_time'] = 'Logge Endzeiten für QSOs separat';
$lang['account_log_end_time_hint'] = 'Wenn aktiviert, werden QSO Endzeiten separat erfasst. Falls nicht, ist die QSO Endzeit gleich der Startzeit.';
$lang['account_measurement_preferences'] = 'Entfernungsformat';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Wähle, wie Datumsfelder angezeigt werden sollen, wenn du eingeloggt bist.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Wähle, in welcher Einheit Entfernungen angezeigt werden sollen.';
$lang['account_cloudlog_language'] = 'Cloudlog Sprache';
$lang['account_choose_cloudlog_language'] = 'Wähle eine Sprache für Cloudlog.';

$lang['account_main_menu'] = 'Hauptmenü';
$lang['account_show_notes_in_the_main_menu'] = 'Zeige Notizen im Hauptmenü';

$lang['account_gridsquare_and_location_autocomplete'] = 'Vervollständigung von Planquadrat und Lokation';
$lang['account_location_auto_lookup'] = 'Automatische Ermittlung der Lokation.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'Wenn aktiviert, wird das Planquadrat basierend auf der Lokation ermittelt.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'Automatische Ermittlung von Planquadrat und Lokation anhand des SOTA Gipfels.';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'Automatische Ermittlung von Planquadrat und Lokation andhand der WWFF Referenz.';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'Automatische Ermittlung des Parknamens anhand der POTA Referenz.';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'Wenn aktiviert, werden Name und Planquadrat über die API ermittelt und gesetzt.';

$lang['account_previous_qsl_type'] = 'QSL Typ der vorherigen QSOs';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Wähle den QSL-Typ für die Anzeige der bereits getätigten QSOs.';

$lang['account_qrzcom_hamqthcom_images'] = 'qrz.com/hamqth.com Bilder';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Zeige das Profilbild des QSO-Partners aus seinem qrz.com/hamqth.com Profil in der QSO Loggen Sektion.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Bitte qrz.com/hamqth.com Zugangsdaten in der Basiskonfigurationsdatei ablegen.';

$lang['account_amsat_status_upload'] = 'AMSAT Status Upload';
$lang['account_upload_status_of_sat_qsos_to'] = 'Status von SAT QSOs hochladen auf';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Logbook of The World (LoTW) Benutzername';
$lang['account_logbook_of_the_world_lotw_password'] = 'Logbook of The World (LoTW) Passwort';
$lang['account_leave_blank_to_keep_existing_password'] = 'Leer lassen um das existierende Passwort zu übernehmen';

$lang['account_clublog'] = 'Club Log';
$lang['account_clublog_email_callsign'] = 'Club Log Email/Rufzeichen';
$lang['account_clublog_password'] = 'Club Log Passwort';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'Die Emailadresse oder Rufzeichen, das für den Club Log Login verwendet wird';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'eQSL.cc Benutzername';
$lang['account_eqslcc_password'] = 'eQSL.cc Passwort';

$lang['account_save_account_changes'] = 'Speichere Kontoänderungen';
$lang['account_create_account'] = 'Konto anlegen';

$lang['account_delete_user_account'] = 'Benutzerkonto löschen';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Bist du sicher, dass du das Benutzerkonto löschen willst';
$lang['account_yes_delete_this_user'] = 'Ja, Benutzerkonto löschen';
$lang['account_no_do_not_delete_this_user'] = 'Nein, Benutzerkonto nicht löschen';

$lang['account_forgot_password'] = 'Passwort vergessen?';
$lang['account_you_can_reset_your_password_here'] = 'Du kannst dein Passwort hier zurücksetzen.';
$lang['account_reset_password'] = 'Passwort zurücksetzen';
$lang['account_the_email_field_is_required'] = 'Die Emailadresse ist erforderlich';
$lang['account_confirm_password'] = 'Bestätige Passwort';

$lang['account_forgot_your_password'] = 'Passwort vergessen?';

$lang['account_login_to_cloudlog'] = 'Anmeldung bei Cloudlog';
$lang['account_login'] = 'Anmeldung';

$lang['account_mastodon'] = 'Mastodonserver';
$lang['account_user_mastodon'] = 'URL des Mastodonservers';
$lang['account_user_mastodon_hint'] = "Haupt-URL des Mastodonservers, z.B. <a href='https://radiosocial.de/' target='_blank'>https://radiosocial.de";

$lang['account_default_band_settings'] = 'Einstellung für Standardband und -bestätigungsmethode';
$lang['account_gridmap_default_band'] = 'Standardband';
$lang['account_qsl_settings'] = 'Standard QSL-Methoden';

$lang['account_winkeyer'] = 'Winkeyer';
$lang['account_winkeyer_hint'] = "Die Winkeyer Unterstützung in Cloudlog ist sehr experimentell. Lese zuerst den Wikieintrag auf <a href='https://github.com/magicbug/Cloudlog/wiki/Winkey' target='_blank'>https://github.com/magicbug/Cloudlog/wiki/Winkey</a> bevor du ihn einschaltest.";
$lang['account_winkeyer_enabled'] = "Winkeyer Features Eingeschaltet";

==> 2.6.10.zip: cloudlog/application/language/german/account_lang.php <==
<?php

defined('BASEPATH') OR exit('Direkter Zugriff auf Skripte ist nicht erlaubt');

$lang['account_logbook_fields'] = 'Logbuchfelder';
$lang['account_column1_text'] = 'Wähle Spalte 1';
$lang['account_column2_text'] = 'Wähle Spalte 2';
$lang['account_column3_text'] = 'Wähle Spalte 3';
$lang['account_column4_text'] = 'Wähle Spalte 4';
$lang['account_column5_text'] = 'Wähle Spalte 5 (nur für Logbuch)';

$lang['account_create_user_account'] = 'Benutzerkonto anlegen';
$lang['account_edit_account'] = 'Benutzerkonto editieren';

$lang['account_account_information'] = 'Benutzerkonto Informationen';
$lang['account_user'] = "Benutzer";
$lang['account_word_edited'] = "bearbeitet";
$lang['account_username'] = 'Benutzername';
$lang['account_email_address'] = 'E-Mail Adresse';
$lang['account_password'] = 'Passwort';

$lang['account_roles'] = 'Rollen';
$lang['account_user_role'] = 'Benutzerrolle';
$lang['account_word_admin'] = 'Admin';

$lang['account_theme'] = 'Thema';
$lang['account_stylesheet'] = 'Stylesheet';

$lang['account_personal_information'] = 'Informationen';
$lang['account_first_name'] = 'Vorname';
$lang['account_last_name'] = 'Nachname';

$lang['account_hamradio_information'] = "Ham Radio";
$lang['account_callsign'] = 'Rufzeichen';
$lang['account_gridsquare'] = 'Planquadrat';

$lang['account_cloudlog_preferences'] = 'Cloudlog Einstellungen';
$lang['account_timezone'] = 'Zeitzone';
$lang['account_date_format'] = 'Datumsformat';
$lang['account_log_end_time'] = 'Logge Endzeiten für QSOs separat';
$lang['account_log_end_time_hint'] = 'Wenn aktiviert, werden QSO Endzeiten separat erfasst. Falls nicht, ist die QSO Endzeit gleich der Startzeit.';
$lang['account_quicklog_feature'] = "Quicklog Feld";
$lang['account_quicklog_feature_hint'] = "Mit dieser Option kannst du Rufzeichen auch direkt aus dem Suchfeld in der Menüleiste heraus loggen.";
$lang['account_quicklog_enter'] = "Quicklog - Aktion mit Enter Taste";
$lang['account_quicklog_enter_hint'] = "Welche Aktion soll ausgeführt werden, wenn Enter gedrückt wird?";
$lang['account_quicklog_enter_log'] = "Logge Rufzeichen";
$lang['account_quicklog_enter_search'] = "Suche Rufzeichen";
$lang['account_measurement_preferences'] = 'Entfernungsformat';
$lang['account_select_how_you_would_like_dates_shown_when_logged_into_your_account'] = 'Wähle, wie Datumsfelder angezeigt werden sollen, wenn du eingeloggt bist.';
$lang['account_choose_which_unit_distances_will_be_shown_in'] = 'Wähle, in welcher Einheit Entfernungen angezeigt werden sollen.';
$lang['account_cloudlog_language'] = 'Cloudlog Sprache';
$lang['account_choose_cloudlog_language'] = 'Wähle eine Sprache für Cloudlog.';

$lang['account_main_menu'] = 'Menü Optionen';
$lang['account_show_notes_in_the_main_menu'] = 'Zeige Notizen im Hauptmenü';

$lang['account_gridsquare_and_location_autocomplete'] = 'Vervollständigung von Planquadrat und Lokation';
$lang['account_location_auto_lookup'] = 'Automatische Ermittlung der Lokation.';
$lang['account_if_set_gridsquare_is_fetched_based_on_location_name'] = 'Wenn aktiviert, wird das Planquadrat basierend auf der Lokation ermittelt.';
$lang['account_sota_auto_lookup_gridsquare_and_name_for_summit'] = 'Automatische Ermittlung von Planquadrat und Lokation anhand des SOTA Gipfels.';
$lang['account_wwff_auto_lookup_gridsquare_and_name_for_reference'] = 'Automatische Ermittlung von Planquadrat und Lokation andhand der WWFF Referenz.';
$lang['account_pota_auto_lookup_gridsquare_and_name_for_park'] = 'Automatische Ermittlung des Parknamens anhand der POTA Referenz.';
$lang['account_if_set_name_and_gridsquare_is_fetched_from_the_api_and_filled_in_location_and_locator'] = 'Wenn aktiviert, werden Name und Planquadrat über die API ermittelt und gesetzt.';

$lang['account_previous_qsl_type'] = 'QSL Typ der vorherigen QSOs';
$lang['account_select_the_type_of_qsl_to_show_in_the_previous_qsos_section'] = 'Wähle den QSL-Typ für die Anzeige der bereits getätigten QSOs.';

$lang['account_qrzcom_hamqthcom_images'] = 'qrz.com/hamqth.com Bilder';
$lang['account_show_profile_picture_of_qso_partner_from_qrzcom_hamqthcom_profile_in_the_log_qso_section'] = 'Zeige das Profilbild des QSO-Partners aus seinem qrz.com/hamqth.com Profil in der QSO Loggen Sektion.';
$lang['account_please_set_your_qrzcom_hamqthcom_credentials_in_the_general_config_file'] = 'Bitte qrz.com/hamqth.com Zugangsdaten in der Basiskonfigurationsdatei ablegen.';

$lang['account_amsat_status_upload'] = 'AMSAT Status Upload';
$lang['account_upload_status_of_sat_qsos_to'] = 'Status von SAT QSOs hochladen auf';

$lang['account_logbook_of_the_world'] = 'Logbook of the World';
$lang['account_logbook_of_the_world_lotw_username'] = 'Logbook of The World (LoTW) Benutzername';
$lang['account_logbook_of_the_world_lotw_password'] = 'Logbook of The World (LoTW) Passwort';
$lang['account_leave_blank_to_keep_existing_password'] = 'Leer lassen um das existierende Passwort zu übernehmen';

$lang['account_clublog'] = 'Club Log';
$lang['account_clublog_email_callsign'] = 'Club Log Email/Rufzeichen';
$lang['account_clublog_password'] = 'Club Log Passwort';
$lang['account_the_email_or_callsign_you_use_to_login_to_club_log'] = 'Die Emailadresse oder Rufzeichen, das für den Club Log Login verwendet wird';

$lang['account_eqsl'] = 'eQSL';
$lang['account_eqslcc_username'] = 'eQSL.cc Benutzername';
$lang['account_eqslcc_password'] = 'eQSL.cc Passwort';

$lang['account_save_account_changes'] = 'Speichere Kontoänderungen';
$lang['account_create_account'] = 'Konto anlegen';

$lang['account_delete_user_account'] = 'Benutzerkonto löschen';
$lang['account_are_you_sure_you_want_to_delete_the_user_account'] = 'Bist du sicher, dass du das Benutzerkonto löschen willst';
$lang['account_yes_delete_this_user'] = 'Ja, Benutzerkonto löschen';
$lang['account_no_do_not_delete_this_user'] = 'Nein, Benutzerkonto nicht löschen';

$lang['account_forgot_password'] = 'Passwort vergessen?';
$lang['account_you_can_reset_your_password_here'] = 'Du kannst dein Passwort hier zurücksetzen.';
$lang['account_reset_password'] = 'Passwort zurücksetzen';
$lang['account_the_email_field_is_required'] = 'Die Emailadresse ist erforderlich';
$lang['account_confirm_password'] = 'Bestätige Passwort';

$lang['account_forgot_your_password'] = 'Passwort vergessen?';

$lang['account_login_to_cloudlog'] = 'Anmeldung bei Cloudlog';
$lang['account_login'] = 'Anmeldung';

$lang['account_mastodon'] = 'Mastodonserver';
$lang['account_user_mastodon'] = 'URL des Mastodonservers';
$lang['account_user_mastodon_hint'] = "Haupt-URL des Mastodonservers, z.B. <a href='https://radiosocial.de/' target='_blank'>https://radiosocial.de";

$lang['account_default_band_settings'] = 'Einstellung für Standardband und -bestätigungsmethode';
$lang['account_gridmap_default_band'] = 'Standardband';
$lang['account_qsl_settings'] = 'Standard QSL-Methoden';

$lang['account_winkeyer'] = 'Winkeyer';
$lang['account_winkeyer_hint'] = "Die Winkeyer Unterstützung in Cloudlog ist sehr experimentell. Lese zuerst den Wikieintrag auf <a href='https://github.com/magicbug/Cloudlog/wiki/Winkey' target='_blank'>https://github.com/magicbug/Cloudlog/wiki/Winkey</a> bevor du ihn einschaltest.";
$lang['account_winkeyer_enabled'] = "Winkeyer Features Eingeschaltet";

$lang['account_map_params'] = "Karten Einstellungen";
$lang['account_map_qso_by_default'] = "QSO (standardmässig)";
$lang['account_map_qso_confirm'] = "QSO (bestätigte)";
$lang['account_map_qso_confirm_same_qso'] = "(Falls 'Nein', wird '".$lang['account_map_qso_by_default']."' verwendet)";

$lang['account_general_information'] = "Generelle Informationen";
$lang['account_qso_logging_options'] = "QSO-Logging Optionen";
$lang['account_third_party_services'] = "Externe Dienste";
$lang['account_default_values'] = "Standardwerte / Favoriten";
$lang['account_miscellaneous'] = "Verschiedenes";

$lang['account_hamsat'] = "Hams.at";
$lang['account_hamsat_private_feed_key'] = "Private Feed Key";
$lang['account_hamsat_hint'] = "Siehe dein Profil unter <a href='https://hams.at/users/settings' target='_blank'>https://hams.at/users/settings</a>.";
$lang['account_hamsat_workable_only'] = "Zeige nur Überflüge an, die gearbeitet werden können";
